@@ -68,7 +68,15 @@ class UnexpectedColumnCountError(ParsingError):
         )
 
 
-class CalculatedAmountDiscrepancy(InvalidTransactionError):
+class UnexpectedRowCountError(ParsingError):
+    """Unexpected row error."""
+
+    def __init__(self, count: int, file: str):
+        """Initialise."""
+        super().__init__(file, f"The following file doesn't have {count} rows:")
+
+
+class CalculatedAmountDiscrepancyError(InvalidTransactionError):
     """Calculated amount discrepancy error."""
 
     def __init__(self, transaction: BrokerTransaction, calculated_amount: Decimal):
