@@ -36,11 +36,7 @@ from .model import (
     HmrcTransactionLog,
     RuleType,
 )
-from .parsers import (
-    read_broker_transactions,
-    read_gbp_prices_history,
-    read_initial_prices,
-)
+from .parsers import read_broker_transactions, read_initial_prices
 from .transaction_log import add_to_list, has_key
 from .util import round_decimal
 
@@ -386,7 +382,9 @@ class CapitalGainsCalculator:
                 # These shares shouldn't be added to Section 104 holding
                 current_amount -= available_quantity * acquisition_price
                 if current_quantity == 0:
-                    assert current_amount == 0, f"current amount {current_amount}"
+                    assert (
+                        round_decimal(current_amount, 23) == 0
+                    ), f"current amount {current_amount}"
                 fees = disposal_fees * available_quantity / original_disposal_quantity
                 calculation_entries.append(
                     CalculationEntry(
@@ -474,7 +472,9 @@ class CapitalGainsCalculator:
                     current_quantity -= available_quantity
                     current_amount -= amount_delta
                     if current_quantity == 0:
-                        assert current_amount == 0, f"current amount {current_amount}"
+                        assert (
+                            round_decimal(current_amount, 23) == 0
+                        ), f"current amount {current_amount}"
                     add_to_list(
                         bed_and_breakfast_list,
                         search_index,
@@ -531,7 +531,9 @@ class CapitalGainsCalculator:
             )
             disposal_quantity = Decimal(0)
 
-        assert disposal_quantity == 0, f"disposal quantity {disposal_quantity}"
+        assert (
+            round_decimal(disposal_quantity, 23) == 0
+        ), f"disposal quantity {disposal_quantity}"
         portfolio[symbol] = (current_quantity, current_amount)
         chargeable_gain = round_decimal(chargeable_gain, 2)
         return chargeable_gain, calculation_entries
@@ -665,7 +667,7 @@ def main() -> int:
     broker_transactions = read_broker_transactions(
         args.schwab, args.schwab_award, args.trading212, args.mssb, args.sharesight
     )
-    converter = CurrencyConverter(read_gbp_prices_history(args.gbp_history))
+    converter = CurrencyConverter(args.exchange_rates_file)
     initial_prices = InitialPrices(read_initial_prices(args.initial_prices))
 
     calculator = CapitalGainsCalculator(
